@@ -4,11 +4,12 @@ from .version import __version__, __dapodik_version__  # NOQA
 from .version import __semester__, __tahun_ajaran__  # NOQA
 
 from .response import DapodikResponse
-from .result import DapodikResult
+from .result import DapodikResult, DapodikResultData
 
 from .auth import BaseAuth
 from .rest import BaseRest
 from .customrest import BaseCustomrest
+from .beranda import BaseBeranda
 from .validasi import BaseValidasi
 from .peserta_didik import BasePesertaDidik
 from .gtk import BaseGtk
@@ -20,6 +21,7 @@ from .dapodik import Dapodik
 
 __all__ = [
     "BaseAuth",
+    "BaseBeranda",
     "BaseCustomrest",
     "BaseGtk",
     "BasePesertaDidik",
@@ -31,4 +33,5 @@ __all__ = [
     "Dapodik",
     "DapodikResponse",
     "DapodikResult",
+    "DapodikResultData",
 ]
