@@ -4,7 +4,7 @@ import json
 import logging
 from cachetools import LRUCache
 from requests import Response, Session
-from typing import Any, Callable, MutableMapping, Optional, List, Type, TypeVar, Union
+from typing import Any, Callable, MutableMapping, Optional, Type, TypeVar, Union
 
 from dapodik.exception import DapodikResponseError, ServerTidakMerespon
 from dapodik.message import DapodikMessage
@@ -76,6 +76,16 @@ class BaseDapodik(object):
             **kwargs,
         )
 
+    def _get_struct(
+        self,
+        filename: str,
+        cl: Type[T],
+        **kwargs,
+    ) -> T:
+        res = self._get(filename, **kwargs)
+        data = json.loads(res.text)
+        return cattr.structure(data, cl)
+
     def _get_rows(
         self,
         path: str,
